@@ -15,6 +15,7 @@
 #define PQXX_CONNECTION_H
 
 #include <map>
+#include <memory>
 #include <stdexcept>
 
 #include "pqxx/transactor.h"
@@ -92,9 +93,29 @@ public:
    * member functions make it necessary to do so.  This regime is referred to as
    * a "lazy" connection.
    */
-  explicit Connection(const PGSTD::string &ConnInfo, 
+  explicit Connection(const PGSTD::string &ConnInfo,
                       bool Immediate=true);				//[t1]
 
+  /// Constructor.  Sets up connection based on PostgreSQL connection string.
+  /** @param ConnInfo a PostgreSQL connection string specifying any required
+   * parameters, such as server, port, database, and password.  As a special
+   * case, a null pointer is taken as the empty string.
+   * @param Immediate if set, makes the connection immediately.  This is the
+   * default.  If not set, the creation of the underlying database connection is
+   * deferred until necessitated by actual use, and the Connection remains in a
+   * deactivated state.  It will be activated transparently when calls to its
+   * member functions make it necessary to do so.  This regime is referred to as
+   * a "lazy" connection.
+   */
+  explicit Connection(const char ConnInfo[], bool Immediate=true);	//[t2]
+
+  // /// Constructor.  Sets up a lazy connection with an empty connect string.
+  // /** Note that this version of Connection is deferred by default, making it
+  //  * easier to create connection pools where not every connection object is
+  //  * going to be used.
+  //  */
+  // Connection();								//[t43]
+
   /// Destructor.  Implicitly closes the connection.
   ~Connection();							//[t1]
 
