@@ -89,7 +89,7 @@ public:
 
   void operator()(argument_type &T)
   {
-    T.Exec(("NOTIFY " + m_Trigger).c_str());
+    T.Exec("NOTIFY " + m_Trigger);
   }
 
   void OnAbort(const char Reason[]) throw ()
@@ -111,7 +111,7 @@ int main(int, char *argv[])
 {
   try
   {
-    Connection C(argv[1] ? argv[1] : "", false);
+    Connection C(argv[1], false);
     cout << "Adding trigger..." << endl;
     TestTrig Trig(C);
 
